tcn_network: Generate network from conversation tweets
Description
Creates the nodes and edges for a Twitter conversation network. An "activity" type network with tweets as nodes, or
an "actor" type with users as nodes can be created.
Usage
tcn_network(data = NULL, type = "actor")
Value
Named list of dataframes for network nodes and edges.
Arguments
data
Named list. Dataframes of threaded conversation tweets and users collected by get_threads function.
type
Character string. Type of network to generate, either "actor" or "activity". Default is "actor".