if (FALSE) {
# get twitter conversation threads by tweet ids or urls
tweet_ids <- c("xxxxxxxx",
"https://twitter.com/xxxxxxxx/status/xxxxxxxx")
tweets <- tcn_threads(tweet_ids, token, endpoint = "recent")
# get twitter conversation threads by tweet ids or urls using historical endpoint
# starting from May 01, 2021.
tweet_ids <- c("xxxxxxxx",
"https://twitter.com/xxxxxxxx/status/xxxxxxxx")
tweets <- tcn_threads(tweet_ids,
token = token,
endpoint = "all",
start_time = "2021-05-01T00:00:00Z")
}
Run the code above in your browser using DataLab